PassManager

Struct PassManager 

pub struct PassManager<'c> { /* private fields */ }
A pass manager.

Implementations

Source

impl PassManager<'_>

pub fn new(context: &Context) -> Self

Creates a pass manager.

pub fn nested_under(&self, name: &str) -> OperationPassManager<'_, '_>

Returns an operation pass manager for nested operations corresponding to a given name.

pub fn add_pass(&self, pass: Pass)

Adds a pass.

pub fn enable_verifier(&self, enabled: bool)

Enables a verifier.

pub fn enable_ir_printing(&self)

Enables IR printing.

pub fn run(&self, module: &mut Module<'_>) -> Result<(), Error>

Runs passes added to a pass manager against a module.

pub fn as_operation_pass_manager(&self) -> OperationPassManager<'_, '_>

Converts a pass manager to an operation pass manager.

pub unsafe fn from_raw(raw: MlirPassManager) -> Self

Creates a PassManager from the given raw pointer.

Safety

Caller must ensure this is a valid PassManager pointer.

pub const fn to_raw(&self) -> MlirPassManager

Gets the raw object of this pass manager.

pub const fn into_raw(self) -> MlirPassManager

Converts a PassManager into an owned raw object.