pub struct PassManager<'c> { /* private fields */ }Expand description
A pass manager.
Implementations
Sourceimpl PassManager<'_>
impl PassManager<'_>
Sourcepub fn nested_under(&self, name: &str) -> OperationPassManager<'_, '_>
pub fn nested_under(&self, name: &str) -> OperationPassManager<'_, '_>
Returns an operation pass manager for nested operations corresponding to a given name.
Sourcepub fn enable_verifier(&self, enabled: bool)
pub fn enable_verifier(&self, enabled: bool)
Enables a verifier.
Sourcepub fn enable_ir_printing(&self)
pub fn enable_ir_printing(&self)
Enables IR printing.
Sourcepub fn run(&self, module: &mut Module<'_>) -> Result<(), Error>
pub fn run(&self, module: &mut Module<'_>) -> Result<(), Error>
Runs passes added to a pass manager against a module.
Sourcepub fn as_operation_pass_manager(&self) -> OperationPassManager<'_, '_>
pub fn as_operation_pass_manager(&self) -> OperationPassManager<'_, '_>
Converts a pass manager to an operation pass manager.
Sourcepub unsafe fn from_raw(raw: MlirPassManager) -> Self
pub unsafe fn from_raw(raw: MlirPassManager) -> Self
Creates a PassManager from the given raw pointer.
Safety
Caller must ensure this is a valid PassManager pointer.
Sourcepub const fn to_raw(&self) -> MlirPassManager
pub const fn to_raw(&self) -> MlirPassManager
Gets the raw object of this pass manager.
Sourcepub const fn into_raw(self) -> MlirPassManager
pub const fn into_raw(self) -> MlirPassManager
Converts a PassManager into an owned raw object.